/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
/*
 * Copyright (C) 2011 David Zeuthen <zeuthen@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __UDISKS_H__
#define __UDISKS_H__

#define __UDISKS_INSIDE_UDISKS_H__
#include <udisks/udiskstypes.h>
#include <udisks/udisksenums.h>
#include <udisks/udisksenumtypes.h>
#include <udisks/udiskserror.h>
#include <udisks/udisks-generated.h>
#include <udisks/udisksclient.h>
#include <udisks/udisksversion.h>
#undef __UDISKS_INSIDE_UDISKS_H__

#endif /* __UDISKS_H__ */
